Gemini client and server implementaion in async Rust with Tokio and Rustls.
You probably need Client::builder().
Features
file-sscv: known_hosts file parser and helper functions for verifying a self-signed certificate.dane: alias tohickory.hickory: custom DNS client, also required for a DANE-based verification.hickory-dot: enables DNS-over-TLS.hickory-doh: enables DNS-over-HTTPS.