StatusCode

Enum StatusCode 

#[repr(u8)]
pub enum StatusCode {
Show 19 variants Input = 10, InputSensitive = 11, Success = 20, TempRedirect = 30, PermRedirect = 31, TempFail = 40, ServerUnavailable = 41, CgiError = 42, ProxyError = 43, SlowDown = 44, PermFail = 50, NotFound = 51, Gone = 52, ProxyRequestRefused = 53, BadRequest = 59, ClientCerts = 60, CertNotAuthorized = 61, CertNotValid = 62, Unknown(u8),
}
2-digit status code enum; all the codes defined in Gemini spec are listed

Variants



Input = 10

User input is expected



InputSensitive = 11

User input with sensitive data such as password is expected



Success = 20

Request has been processed successfully, content is served



TempRedirect = 30

Temporary redirection to another URL



PermRedirect = 31

Permanent redirection to another URL



TempFail = 40

General status code for temporary failures



ServerUnavailable = 41

Server is unavailable due to overload or maintenance



CgiError = 42

CGI process returned an error or timed out



ProxyError = 43

Request to a remote host was not successful



SlowDown = 44

Client must slow down requests (some kind of ratelimit)



PermFail = 50

General status code for permanent failures



NotFound = 51

Requested resource was not found



Gone = 52

Requested resource is no longer available



ProxyRequestRefused = 53

Given URL is not meant to be processed by this server (host does not match, scheme is not gemini://, etc.), but the server does not accept proxy requests



BadRequest = 59

Server is unable to parse the request



ClientCerts = 60

Client certificate is required to access the content



CertNotAuthorized = 61

Provided certificate is not authorized for accessing this resource



CertNotValid = 62

Provided certificate is not valid: violates X.509 standard, has invalid signature or expiry date



Unknown(u8)

Undefined status code between 10 and 69 inclusive