pub enum LibError {
IoError(Error),
InvalidUrlError(InvalidUrl),
HostLookupError,
RustlsError(Error),
StatusOutOfRange(u8),
DataNotUtf8(FromUtf8Error),
InvalidMime(FromStrError),
DnsClientError(ClientError),
}Expand description
Main error structure, also a wrapper for everything else
Variants
IoError(Error)
General I/O error
InvalidUrlError(InvalidUrl)
URL parse or check error
HostLookupError
DNS server has provided no suitable records (e. g. domain does not exist)
RustlsError(Error)
TLS library error related to certificate/signature verification failure or connection failure
StatusOutOfRange(u8)
Response status code is out of [10; 69] range
DataNotUtf8(FromUtf8Error)
Response metadata or content cannot be parsed as a UTF-8 string without errors
InvalidMime(FromStrError)
Provided string is not a valid MIME type
DnsClientError(ClientError)
Hickory DNS client error
Implementations